@@ -6,7 +6,7 @@ QErrorMessage::QErrorMessage()
 
 }
 
-QErrorMessage::QErrorMessage(int code, QString text)
+QErrorMessage::QErrorMessage(QString code, QString text)
 {
     this->code = code;
     this->text = text;
