@@ -287,13 +287,8 @@ AlbumList ServiceMgr::getAlbums(bool isNeedUpdate, bool useSignal)
 {
     AlbumList ret;
 
-    for (int i = 0; i < this->accounts.length(); i++) {
-        ret.append(this->getAlbums(this->accounts.at(i)->getProfile(false), isNeedUpdate, false));
-    }
-
-    qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): this->albumsUpdate=" << this->albumsUpdate;
-    if (useSignal && this->accounts.length() > 0)
-        emit this->updateAlbumList(this->accounts.at(0)->getProfile(false), ret, this->albumsUpdate > 0 ? false: true);
+    if (this->accounts.length() > 0)
+        return this->getAlbums(this->accounts.at(0)->getProfile(false), isNeedUpdate, useSignal);
 
     return ret;
 }
@@ -306,7 +301,21 @@ AlbumList ServiceMgr::getAlbums(const Friend& curFriend, bool isNeedUpdate, cons
             << " from " << curFriend.accountId << " needUpdate=" << isNeedUpdate << "; this->albumsUpdate="
             << this->albumsUpdate;
 
-    ret = curFriend.getAlbumList();
+    // check for owner album
+    for (int i = 0; i < this->accounts.length(); i++) {
+        if (this->accounts.at(i)->accountId().compare(curFriend.accountId) == 0 &&
+            this->accounts.at(i)->getProfile(false).ownerId.compare(curFriend.ownerId) == 0)
+        {
+            for (int j = 0; j < this->accounts.length(); j++) {
+                if (this->accounts.at(j)->getAlbumList().isEmpty())
+                    isNeedUpdate = true;
+                ret.append(this->accounts.at(j)->getAlbumList());
+            }
+        }
+    }
+
+    if (ret.length() == 0)
+        ret = curFriend.getAlbumList();
 
     this->cleanThreads();
 
